package javax.accessibility;

import java.util.Vector;

public class AccessibleRelationSet
{
    protected Vector<AccessibleRelation> relations;
    
    public AccessibleRelationSet() {
        this.relations = null;
        this.relations = null;
    }
    
    public AccessibleRelationSet(AccessibleRelation[] array) {
        this.relations = null;
        if (array.length != 0) {
            this.relations = new Vector(array.length);
            for (int i = 0; i < array.length; ++i) {
                this.add(array[i]);
            }
        }
    }
    
    public boolean add(AccessibleRelation obj) {
        if (this.relations == null) {
            this.relations = new Vector();
        }
        AccessibleRelation value = this.get(obj.getKey());
        if (value == null) {
            this.relations.addElement(obj);
            return true;
        }
        Object[] target = value.getTarget();
        Object[] target2 = obj.getTarget();
        int n = target.length + target2.length;
        Object[] target3 = new Object[n];
        for (int i = 0; i < target.length; ++i) {
            target3[i] = target[i];
        }
        for (int j = target.length, n2 = 0; j < n; ++j, ++n2) {
            target3[j] = target2[n2];
        }
        value.setTarget(target3);
        return true;
    }
    
    public void addAll(AccessibleRelation[] array) {
        if (array.length != 0) {
            if (this.relations == null) {
                this.relations = new Vector(array.length);
            }
            for (int i = 0; i < array.length; ++i) {
                this.add(array[i]);
            }
        }
    }
    
    public boolean remove(AccessibleRelation obj) {
        return this.relations != null && this.relations.removeElement(obj);
    }
    
    public void clear() {
        if (this.relations != null) {
            this.relations.removeAllElements();
        }
    }
    
    public int size() {
        if (this.relations == null) {
            return 0;
        }
        return this.relations.size();
    }
    
    public boolean contains(String s) {
        return this.get(s) != null;
    }
    
    public AccessibleRelation get(String anObject) {
        if (this.relations == null) {
            return null;
        }
        int size = this.relations.size();
        int i = 0;
        while (i < size) {
            AccessibleRelation accessibleRelation = (AccessibleRelation)this.relations.elementAt(i);
            if (accessibleRelation != null && accessibleRelation.getKey().equals(anObject)) {
                return accessibleRelation;
            }
            ++i;
        }
        return null;
    }
    
    public AccessibleRelation[] toArray() {
        if (this.relations == null) {
            return new AccessibleRelation[0];
        }
        AccessibleRelation[] array = new AccessibleRelation[this.relations.size()];
        for (int i = 0; i < array.length; ++i) {
            array[i] = (AccessibleRelation)this.relations.elementAt(i);
        }
        return array;
    }
    
    @Override
    public String toString() {
        String str = "";
        if (this.relations != null && this.relations.size() > 0) {
            str = ((AccessibleRelation)this.relations.elementAt(0)).toDisplayString();
            for (int i = 1; i < this.relations.size(); ++i) {
                str = str + "," + ((AccessibleRelation)this.relations.elementAt(i)).toDisplayString();
            }
            return str;
        }
        return str;
    }
}
